@@ -11,7 +11,9 @@ def pydantic_offsetlimit_creator(schema: Type[pydantic.BaseModel]) -> Type[pydan
 
     lname = f"{schema.__name__}_paging"
 
-    properties = {"__annotations__": {"data": List[schema]}, "total": int}  # type: ignore
+    properties = {
+        "__annotations__": {"data": List[schema], "total": int},
+    }  # type: ignore
     model = cast(Type[PydanticListModel], type(lname, (PydanticListModel,), properties))
     setattr(model.__config__, "title", f"{getattr(schema.__config__, 'title')}_limitoffset")
     return model
